#!/bin/bash
# ============LICENSE_START=======================================================
#  Copyright (C) 2020 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o errexit
set -o nounset
set -o pipefail

# Turn PROJECTS, BRANCHES and PROJECT_DIRECTORIES paramter strings into arrays
# Required in order to loop through them
PROJECTS=(`echo $PROJECTS | sed 's/,/\n/g'`)
BRANCHES=(`echo $BRANCHES | sed 's/,/\n/g'`)
PROJECT_DIRECTORIES=(`echo $PROJECT_DIRECTORIES | sed 's/,/\n/g'`)
# if commitids/project versions are given turn string into an array
PROJECT_VERSIONS=(`echo $PROJECT_VERSIONS | sed 's/,/\n/g'`) || echo "No project versions/commit ids specificed, latest sources will be used"

# Find and store array lenth of one of the arrays
ARRAY_LENGTH=$(echo ${#PROJECTS[@]})
# Take 1 of the array length for the loop
((ARRAY_LENGTH--))

# Create project directories and clone source repositories into them
for i in $(seq 0 $ARRAY_LENGTH)
do
  echo "----------------------------------------------------"
  echo "Info: Creating project directory ${PROJECT_DIRECTORIES[$i]}"
  echo "----------------------------------------------------"
  mkdir -p $WORKSPACE/${PROJECT_DIRECTORIES[$i]}

  echo "----------------------------------------------------"
  echo "Info: Cloning ${PROJECTS[$i]} branch ${BRANCHES[$i]} into ${PROJECT_DIRECTORIES[$i]}"
  echo "----------------------------------------------------"
  git clone --single-branch --branch ${BRANCHES[$i]} $GIT_BASE_HTTPS${PROJECTS[$i]} $WORKSPACE/${PROJECT_DIRECTORIES[$i]}

  if ((${#PROJECT_VERSIONS[@]})); then
    echo "----------------------------------------------------"
    echo "Info: Checking out ${PROJECTS[$i]} to commit ${PROJECT_VERSIONS[$i]}"
    echo "----------------------------------------------------"
    cd $WORKSPACE/${PROJECT_DIRECTORIES[$i]}
    git checkout ${PROJECT_VERSIONS[$i]}
    cd $WORKSPACE
  else
    cd $WORKSPACE
  fi
done
